

SCSQuery
=====================

.. currentmodule:: pyvo.dal.scs

.. autoclass:: SCSQuery
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~SCSQuery.dec
      ~SCSQuery.pos
      ~SCSQuery.ra
      ~SCSQuery.radius
      ~SCSQuery.sr
      ~SCSQuery.std_parameters
      ~SCSQuery.verbosity

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~SCSQuery.execute_votable

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: dec
   .. autoattribute:: pos
   .. autoattribute:: ra
   .. autoattribute:: radius
   .. autoattribute:: sr
   .. autoattribute:: std_parameters
   .. autoattribute:: verbosity

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: execute_votable

   
   